summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecommandhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetecommandhandler.h')
-rw-r--r--kopete/libkopete/kopetecommandhandler.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/kopete/libkopete/kopetecommandhandler.h b/kopete/libkopete/kopetecommandhandler.h
index f763ace6..9632f872 100644
--- a/kopete/libkopete/kopetecommandhandler.h
+++ b/kopete/libkopete/kopetecommandhandler.h
@@ -17,7 +17,7 @@
#ifndef _KOPETECOMMANDHANDLER_H_
#define _KOPETECOMMANDHANDLER_H_
-#include <qdict.h>
+#include <tqdict.h>
#include <kshortcut.h>
#include "kopetemessage.h"
@@ -38,7 +38,7 @@ class Plugin;
class Protocol;
class Command;
-typedef QDict<Command> CommandList;
+typedef TQDict<Command> CommandList;
/**
* @author Jason Keirstead <jason@keirstead.org>
@@ -76,7 +76,7 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param parent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
* accept two parameters, a QString of arguments, and a Kopete::ChatSession
* pointer to the manager under which the command was sent.
* @param help An optional help string to be shown when the user uses
* /help \<command\>
@@ -85,9 +85,9 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param cut a default keyboard shortcut
* @param pix icon name, the icon will be shown in menus
*/
- void registerCommand( QObject *parent, const QString &command, const char* handlerSlot,
- const QString &help = QString::null, uint minArgs = 0, int maxArgs = -1,
- const KShortcut &cut = 0, const QString &pix = QString::null );
+ void registerCommand( TQObject *parent, const TQString &command, const char* handlerSlot,
+ const TQString &help = TQString::null, uint minArgs = 0, int maxArgs = -1,
+ const KShortcut &cut = 0, const TQString &pix = TQString::null );
/**
* \brief Register a command alias.
@@ -106,15 +106,15 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param cut a default keyboard shortcut
* @param pix icon name, the icon will be shown in menus
*/
- void registerAlias( QObject *parent,
- const QString &alias,
- const QString &formatString,
- const QString &help = QString::null,
+ void registerAlias( TQObject *parent,
+ const TQString &alias,
+ const TQString &formatString,
+ const TQString &help = TQString::null,
CommandType = SystemAlias,
uint minArgs = 0,
int maxArgs = -1,
const KShortcut &cut = 0,
- const QString &pix = QString::null );
+ const TQString &pix = TQString::null );
/**
* \brief Unregister a command.
@@ -126,16 +126,16 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param parent The plugin who owns this command
* @param command The command to unload
*/
- void unregisterCommand( QObject *parent, const QString &command );
+ void unregisterCommand( TQObject *parent, const TQString &command );
/**
* \brief Unregister an alias.
*
* \see unregisterCommand( QObject *parent, const QString &command )
* @param parent The plugin who owns this alias
* @param alias The alais to unload
*/
- void unregisterAlias( QObject *parent, const QString &alias );
+ void unregisterAlias( TQObject *parent, const TQString &alias );
/**
* \brief Process a message to see if any commands should be handled
@@ -150,17 +150,17 @@ class KOPETE_EXPORT CommandHandler : public QObject
* \brief Process a message to see if any commands should be handled
*
* \see processMessage( Kopete::Message &msg, Kopete::ChatSession *manager)
* \param msg A QString contain the message
* \param manager the Kopete::ChatSession who will own the message
* \return true if the command was handled, false if the command was not handled.
*/
- bool processMessage( const QString &msg, ChatSession *manager );
+ bool processMessage( const TQString &msg, ChatSession *manager );
/**
* Parses a string of command arguments into a QStringList. Quoted
* blocks within the arguments string are treated as one argument.
*/
- static QStringList parseArguments( const QString &args );
+ static TQStringList parseArguments( const TQString &args );
/**
* \brief Check if a command is already handled
@@ -168,7 +168,7 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param command The command to check
* @return True if the command is already being handled, False if not
*/
- bool commandHandled( const QString &command );
+ bool commandHandled( const TQString &command );
/**
* \brief Check if a command is already handled by a spesific protocol
@@ -177,24 +177,24 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param protocol The protocol to check
* @return True if the command is already being handled, False if not
*/
- bool commandHandledByProtocol( const QString &command, Protocol *protocol);
+ bool commandHandledByProtocol( const TQString &command, Protocol *protocol);
private slots:
void slotPluginLoaded( Kopete::Plugin * );
- void slotPluginDestroyed( QObject * );
+ void slotPluginDestroyed( TQObject * );
void slotExecReturnedData(KProcess *proc, char *buff, int bufflen );
void slotExecFinished(KProcess *proc);
void slotViewCreated( KopeteView *view );
- void slotHelpCommand( const QString & args, Kopete::ChatSession *manager );
- void slotClearCommand( const QString & args, Kopete::ChatSession *manager );
- void slotPartCommand( const QString & args, Kopete::ChatSession *manager );
- void slotCloseCommand( const QString & args, Kopete::ChatSession *manager );
- //void slotMeCommand( const QString & args, Kopete::ChatSession *manager );
- void slotExecCommand( const QString & args, Kopete::ChatSession *manager );
- void slotAwayCommand( const QString & args, Kopete::ChatSession *manager );
- void slotAwayAllCommand( const QString & args, Kopete::ChatSession *manager );
- void slotSayCommand( const QString & args, Kopete::ChatSession *manager );
+ void slotHelpCommand( const TQString & args, Kopete::ChatSession *manager );
+ void slotClearCommand( const TQString & args, Kopete::ChatSession *manager );
+ void slotPartCommand( const TQString & args, Kopete::ChatSession *manager );
+ void slotCloseCommand( const TQString & args, Kopete::ChatSession *manager );
+ //void slotMeCommand( const TQString & args, Kopete::ChatSession *manager );
+ void slotExecCommand( const TQString & args, Kopete::ChatSession *manager );
+ void slotAwayCommand( const TQString & args, Kopete::ChatSession *manager );
+ void slotAwayAllCommand( const TQString & args, Kopete::ChatSession *manager );
+ void slotSayCommand( const TQString & args, Kopete::ChatSession *manager );
private:
/**
@@ -76,7 +76,7 @@ class KOPETE_EXPORT CommandHandler : public QObject
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
- * accept two parameters, a QString of arguments, and a Kopete::ChatSession
+ * accept two parameters, a TQString of arguments, and a Kopete::ChatSession
* pointer to the manager under which the command was sent.
* @param help An optional help string to be shown when the user uses
@@ -126,16 +126,16 @@ class KOPETE_EXPORT CommandHandler : public QObject
* \brief Unregister an alias.
*
- * \see unregisterCommand( QObject *parent, const QString &command )
+ * \see unregisterCommand( TQObject *parent, const TQString &command )
* @param parent The plugin who owns this alias
* @param alias The alais to unload
@@ -150,17 +150,17 @@ class KOPETE_EXPORT CommandHandler : public QObject
*
* \see processMessage( Kopete::Message &msg, Kopete::ChatSession *manager)
- * \param msg A QString contain the message
+ * \param msg A TQString contain the message
* \param manager the Kopete::ChatSession who will own the message
* \return true if the command was handled, false if the command was not handled.
@@ -150,17 +150,17 @@ class KOPETE_EXPORT CommandHandler : public QObject
/**
- * Parses a string of command arguments into a QStringList. Quoted
+ * Parses a string of command arguments into a TQStringList. Quoted
* blocks within the arguments string are treated as one argument.
*/